/*
*  AstronomicalUnits - The astronomy length unit "astronomical unit, AU".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The astronomical length unit: astronomical unit.
*       Definition: AU/m = 1/149.59855e+9
*  </p>
*
*  <p>  Is Exact?:  No  </p>
*
*  <p>	Modified by:	Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 15, 1998
*  @version  February 5, 2000
**/
public final class AstronomicalUnits extends LengthUnit {

	private static AstronomicalUnits example = new AstronomicalUnits();

	private AstronomicalUnits() {
		name = "astronomical units";
		abv = "AU";
	}

	//	Returns the number of angstroms in a meter.
	static final double theFactor = 1. / 149.59855e+9;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static AstronomicalUnits getInstance() {
		return example;
	}


}


