/*
*  Centipoise - Dynamic viscosity unit "centipoise".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The dynamic viscosity unit: centipoise.
*       Definition: centipoise/poise = 100  </p>
*
*  <p>  Note: This is a mass equivelent unit.  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 31, 1999
*  @version  November 17, 1999
**/
public final class Centipoise extends DynViscosityUnit {

	private static Centipoise example = new Centipoise();

	private Centipoise() {
		name = "centipoise";
		abv = "centipoise";
		exact = true;
	}

	//	Returns the number of centipoise in a poise.
	static final double theFactor = 100.0;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static Centipoise getInstance() {
		return example;
	}


}


