/*
*  CubicCentimeters - Volume unit "cubic centimeters".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The volume unit: cubic centimeters.
*       Definition:  cm^3/L = 1000  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 18, 1997
*  @version  November 19, 1999
**/
public final class CubicCentimeters extends VolumeUnit {

	private static CubicCentimeters example = new CubicCentimeters();

	private CubicCentimeters() {
		name = "cubic centimeters";
		abv = "cm\u00B3";
		exact = true;
	}

	//	Returns the number of cubic centimeters in a liter.
	static final double theFactor = 1000.;

	protected double factor() {
		return theFactor;
	}

	/**
	*	Return a reference to the one and only instance of this class.
	**/
	public static CubicCentimeters getInstance() {
		return example;
	}


}


