/*
*  DegCelsius - The SI temperature unit "degrees celsius".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The temperature unit: degrees celsius.
*       Definition: C = K - 273.15  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 18, 1997
*  @version  November 19, 1999
**/
public final class DegCelsius extends TemperatureUnit {
	private static DegCelsius example = new DegCelsius();

	private DegCelsius() {
		name = "degrees Celsius";
		abv = "\u00B0C";
		exact = true;
	}

	//	Returns the number of degrees C in a degree K.
	static final double theFactor = 1.0;
	protected double factor() { return theFactor; }
	
	//	Returns the offset between degrees C and degrees K.
	protected double offset() { return 273.15; }


	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static DegCelsius getInstance() {
		return example;
	}

}


