/*
*  DegRankine - The US temperature unit "degree rankine".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The temperature unit: degrees rankine.
*       Definition: R = F + 459.67  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 18, 1997
*  @version  November 19, 1999
**/
public final class DegRankine extends TemperatureUnit {
	private static DegRankine example = new DegRankine();

	private DegRankine() {
		name = "degrees Rankine";
		abv = "\u00B0R";
		exact = true;
	}

	//	Returns the number of degrees R in a degree K.
	static final double theFactor = DegFarenheit.theFactor;
	protected double factor() { return theFactor; }
	
	//	Returns the offset between degrees R and degrees K.
	protected double offset() { return 0.; }


	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static DegRankine getInstance() {
		return example;
	}

}


