/*
*  Degrees - Angular unit "degrees".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The angular unit: degrees.
*       Definition: deg/rad = 180/PI  </p>
*
*  <p>  Is Exact?: Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date: December 18, 1997
*  @version  May 19, 2002
**/
public final class Degrees extends AngularUnit {

	private static Degrees example = new Degrees();

	private Degrees() {
		name = "degrees";
		abv = "deg";
		exact = true;
	}

	static final double theFactor = 180. / Math .PI;

	/**
	*  Returns the number of degrees in a radian.
	**/
	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static Degrees getInstance() {
		return example;
	}


}


