/**
*  DryQuarts - US dry volume unit "quarts".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The volume unit:  US dry quarts.
*       Definition:  qt/bushels = 32  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 15, 1998
*  @version  November 20, 1999
**/
public final class DryQuarts extends VolumeUnit {

	private static DryQuarts example = new DryQuarts();

	private DryQuarts() {
		name = "US fluid quarts";
		abv = "qt";
		exact = true;
	}

	//	Returns the number of US dry quarts in a liter.
	static final double theFactor = Bushels.theFactor * 32.;

	protected double factor() {
		return theFactor;
	}

	/**
	*	Return a reference to the one and only instance of this class.
	**/
	public static DryQuarts getInstance() {
		return example;
	}


}


