/*
*  FeetPerMinute - The US speed unit "feet per minute".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The British speed unit: feet/minute.
*       Definition: (ft/min)/(m/s) = 1/0.3048 ft/s * 60 s/min  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 17, 1998
*  @version  November 19, 1999
**/
public final class FeetPerMinute extends SpeedUnit {
	private static FeetPerMinute example = new FeetPerMinute();

	private FeetPerMinute() {
		name = "feet per minute";
		abv = "fpm";
		exact = true;
	}

	//	Returns the number of ft/min in a meter/second.
	static final double theFactor = FeetPerSecond.theFactor*60.;
	protected double factor() { return theFactor; }


	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static FeetPerMinute getInstance() {
		return example;
	}

}


