/**
*  ImpGallons - British volume unit "imperial gallons".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The volume unit: British imperial gallons.
*       Definition:  gal (imp)/L = 1/4.54609  </p>
*
*  <p>  NB:  Volume of 10 lb H2O at 62 F  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 18, 1997
*  @version  November 19, 1999
**/
public final class ImpGallons extends VolumeUnit {

	private static ImpGallons example = new ImpGallons();

	private ImpGallons() {
		name = "British imperial gallons";
		abv = "gal (imp)";
		exact = true;
	}

	//	Returns the number of imperial gallons in a liter.
	static final double theFactor = 1. / 4.54609;

	protected double factor() {
		return theFactor;
	}

	/**
	*	Return a reference to the one and only instance of this class.
	**/
	public static ImpGallons getInstance() {
		return example;
	}


}


