/*
*  InvCentimeters - Inverse SI length unit "1/centimeters".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The SI length unit: 1/centimeter.
*       Definition: (1/cm)/(1/m) = 1/100  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  February 1, 1999
*  @version  November 17, 1999
**/
public final class InvCentimeters extends InvLengthUnit {

	private static InvCentimeters example = new InvCentimeters();

	private InvCentimeters() {
		name = "per centimeters";
		abv = "1/cm";
		exact = true;
	}

	//	Returns the number of inverse centimeters in an inverse meter.
	static final double theFactor = 1. / 100.;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static InvCentimeters getInstance() {
		return example;
	}


}


