/*
*  InvNauticalMiles - Inverse length unit "1/nautical miles".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The British length unit: 1/nautical miles.
*       Definition: (1/n mi)/(1/m) = 1852  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  February 1, 1999
*  @version  November 17, 1999
**/
public final class InvNauticalMiles extends InvLengthUnit {

	private static InvNauticalMiles example = new InvNauticalMiles();

	private InvNauticalMiles() {
		name = "per nautical miles";
		abv = "1/n mi";
		exact = true;
	}

	//	Returns the number of inverse nautical miles in an inverse meter.
	static final double theFactor = 1852.;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static InvNauticalMiles getInstance() {
		return example;
	}


}


