/*
*  KilogramsPerMeter3 - Density unit "kilograms per cubic meter".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The SI density unit:  kilograms per cubic meter.
*       Definition: (kg/m^3)/(kg/L) = 1000   </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 8, 1998
*  @version  November 17, 1999
**/
public final class KilogramsPerMeter3 extends DensityUnit {

	private static KilogramsPerMeter3 example = new KilogramsPerMeter3();

	private KilogramsPerMeter3() {
		name = "kilograms per m\u00B3";
		abv = "kg/m\u00B3";
		exact = true;
	}

	//	Returns the number of kg/m^3 in a kg/L.
	static final double theFactor = 1000.;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static KilogramsPerMeter3 getInstance() {
		return example;
	}

}


