/*
*  Kilometers - The SI length unit "kilometers".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The SI length unit: kilometer.
*       Definition: km/m = 0.001
*  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 16, 1997
*  @version  February 5, 2000
**/
public final class Kilometers extends LengthUnit {

	private static Kilometers example = new Kilometers();

	private Kilometers() {
		name = "kilometers";
		abv = "km";
		exact = true;
	}

	//	Returns the number of kilometers in a meter.
	static final double theFactor = 1.e-3;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static Kilometers getInstance() {
		return example;
	}

}


