/*
*  KilometersPerHour - The SI speed unit "kilometers per hour".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The SI speed unit: kilometers/hour.
*       Definition: (km/hr)/(m/s) = 3.6  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 13, 1998
*  @version  November 19, 1999
**/
public final class KilometersPerHour extends SpeedUnit {
	private static KilometersPerHour example = new KilometersPerHour();

	private KilometersPerHour() {
		name = "kilometers per hour";
		abv = "km/hr";
		exact = true;
	}

	//	Returns the number of km/hr in a meter/second.
	static final double theFactor = 3.6;
	protected double factor() { return theFactor; }


	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static KilometersPerHour getInstance() {
		return example;
	}

}


