/*
*  LengthUnit - Base class for all length unit objects.
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  An abstract class that serves as the base class for various
*  length units such as meters, feet, miles, inches, etc.
*  The reference unit for this class is "Meters".
*
*  <p>  Modified by:	Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 16, 1997
*  @version  May 19, 2002
**/
public abstract class LengthUnit extends Unit {

	/**
	*  Converts a value with the current units to a value with
	*  the new units specified.
	*
	*  @param   value   The value in the "currentUnits" to be converted to "newUnit".
	*  @param   newUnit The new unit system to convert value to.
	*  @return  The value converted to the new units.
	**/
	public double convert( double value, Unit newUnit ) throws CannotConvertException {
		if ( ! (newUnit instanceof LengthUnit) ) {
			String oldName = this.getClass().getName();
			String newName = newUnit.getClass().getName();
			throw new CannotConvertException( oldName + " to " + newName );
		}
		value *= newUnit.factor() / this.factor();
		return value;
	}

	/**
	*  Returns the reference unit for this unit type.
	*
	*  @return  The reference unit for this type of unit object.
	**/
	public Unit getRefUnit() {
		return Meters .getInstance();
	}

}


