/*
*  Meters - SI Reference Length unit "meters".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The SI length unit: meter.
*       This is the reference unit for the length unit type.
*  </p>
*
*  <p>  NB: The meter is the distance light travels in a vacuum,
*           in 1/299792458th of a second.
*  </p>
*
*  <p>  Modified by:	Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 16, 1997
*  @version  May 19, 2002
**/
public final class Meters extends LengthUnit {

	private static Meters example = new Meters();

	private Meters() {
		name = "meters";
		abv = "m";
		exact = true;
	}

	static final double theFactor = 1.0;

	/**
	*  Returns the number of meters in a meter.
	**/
	protected double factor() {
		return theFactor;
	}

	/**
	*	Return a reference to the one and only instance of this class.
	**/
	public static Meters getInstance() {
		return example;
	}


}


