/*
*  Microns - The SI length unit "microns".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The SI length unit: micron.
*       Definition: mu/m = <1.e6>		</p>
*
*  <p>  Is Exact?:  Yes		</p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 16, 1997
*  @version  February 5, 2000
**/
public final class Microns extends LengthUnit {

	private static Microns example = new Microns();

	private Microns() {
		name = "microns";
		abv = "\u00B5";
		exact = true;
	}

	//	Returns the number of microns in a meter.
	static final double theFactor = 1.e6;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static Microns getInstance() {
		return example;
	}


}


