/*
*  MilligramsPerMilliliter - Density unit "milligrams per milliliter".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The SI density unit: milligrams per milliliter.
*       Definition: (mg/mL)/(kg/L) = 1000   </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 8, 1998
*  @version  November 17, 1999
**/
public final class MilligramsPerMilliliter extends DensityUnit {

	private static MilligramsPerMilliliter example = new MilligramsPerMilliliter();

	private MilligramsPerMilliliter() {
		name = "milligrams per mL";
		abv = "mg/mL";
		exact = true;
	}

	//	Returns the number of mg/mL in a kg/L.
	static final double theFactor = 1000.;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static MilligramsPerMilliliter getInstance() {
		return example;
	}


}


