/*
*  NauticalMiles - The English length unit "nautical miles".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The British length unit: nautical miles.
*       Definition: n mi/m = 1/1852
*  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 16, 1997
*  @version  February 5, 2000
**/
public final class NauticalMiles extends LengthUnit {

	private static NauticalMiles example = new NauticalMiles();

	private  NauticalMiles() {
		name = "nautical miles";
		abv = "n mi";
		exact = true;
	}

	//	Returns the number of nautical miles in a meter.
	static final double theFactor = 1. / 1852.;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static NauticalMiles getInstance() {
		return example;
	}


}


