/*
*  NewtonsPerSqCentimeter - The SI pressure unit "newtons per square centimeter".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The SI pressure unit: Newtons per square centimeter.
*       Definition: (N/cm^2)/(N/m^2) = 0.0001  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 12, 1998
*  @version  November 19, 1999
**/
public final class NewtonsPerSqCentimeter extends PressureUnit {
	private static NewtonsPerSqCentimeter example = new NewtonsPerSqCentimeter();

	private NewtonsPerSqCentimeter() {
		name = "Newtons per cm\u00B2";
		abv = "N/cm\u00B2";
		exact = true;
	}

	//	Returns the number of N/cm^2 in a N/m^2.
	static final double theFactor = 0.0001;
	protected double factor() { return theFactor; }


	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static NewtonsPerSqCentimeter getInstance() {
		return example;
	}

}


