/*
*  NewtonsSecondPerSqMeter - Dynamic viscosity unit "Newton-second per square meter".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The dynamic viscosity unit: pounds newton-second/m^2.
*       Definition: (N-sec/m^2)/poise = 0.100/9.80665  </p>
*
*  <p>  Is Exact?:  No  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 31, 1999
*  @version  November 17, 1999
**/
public final class NewtonsSecondPerSqMeter extends DynViscosityUnit {

	private static NewtonsSecondPerSqMeter example = new NewtonsSecondPerSqMeter();

	//	Abreviation of this unit.
	private NewtonsSecondPerSqMeter() {
		name = "newtons-second per square meter";
		abv = "N-sec/m\u00B2";
	}

	//	Returns the number of N-sec/m^2 in a poise.
	static final double theFactor = 0.100 / 9.80665;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static NewtonsSecondPerSqMeter getInstance() {
		return example;
	}


}


