/*
*  OuncesPerInch3 - Density unit "ounces per cubic inch".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The British density unit: ounces per cubic inch.
*       Definition: (oz/in^3)/(lb/ft^3) = 16/1728   </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 17, 1998
*  @version  November 17, 1999
**/
public final class OuncesPerInch3 extends DensityUnit {

	private static OuncesPerInch3 example = new OuncesPerInch3();

	private OuncesPerInch3() {
		name = "ounces per in\u00B3";
		abv = "oz/in\u00B3";
		exact = true;
	}

	//	Returns the number of ounces/ft^3 in a kg/L.
	static final double theFactor = PoundsPerFoot3.theFactor*16./1728.;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static OuncesPerInch3 getInstance() {
		return example;
	}


}


