/*
*  PoundsPerFeetSecond - Dynamic viscosity unit "pounds per feet-second".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The dynamic viscosity unit: pounds mass / ft-sec.
*       Definition: (lb/ft-sec)/poise = 6.720E-2  </p>
*
*  <p>  Note: This is a mass equivelent unit.  </p>
*
*  <p>  Is Exact?:  No  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 31, 1999
*  @version  November 17, 1999
**/
public final class PoundsPerFeetSecond extends DynViscosityUnit {

	private static PoundsPerFeetSecond example = new PoundsPerFeetSecond();

	//	Abreviation of this unit.
	private PoundsPerFeetSecond() {
		name = "pounds per feet-second";
		abv = "lb/ft-sec";
	}

	//	Returns the number of lb/ft-sec in a poise.
	static final double theFactor = 6.720E-2;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static PoundsPerFeetSecond getInstance() {
		return example;
	}


}


