/*
*  PoundsPerFoot3 - Density unit "pounds per cubic foot".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The British density unit: pounds per cubic foot.
*       Definition: (lb/ft^3)(kg/L) = 28.316846592/0.45359237  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 8, 1998
*  @version  November 17, 1999
**/
public final class PoundsPerFoot3 extends DensityUnit {

	private static PoundsPerFoot3 example = new PoundsPerFoot3();

	private PoundsPerFoot3() {
		name = "pounds per ft\u00B3";
		abv = "lb/ft\u00B3";
		exact = true;
	}

	//	Returns the number of lbs/ft^3 in a kg/L.
	static final double theFactor = 28.316846592 / 0.45359237;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static PoundsPerFoot3 getInstance() {
		return example;
	}

}


