/*
*  PoundsPerGallon - Density unit "pounds per gallon".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The US density unit: pounds per US fluid gallon.
*       Definition: (lb/gal)(kg/L) = 3.785411784/0.45359237  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 8, 1998
*  @version  November 17, 1999
**/
public final class PoundsPerGallon extends DensityUnit {

	private static PoundsPerGallon example = new PoundsPerGallon();

	private PoundsPerGallon() {
		name = "pounds per US fluid gallon";
		abv = "lb/gal";
		exact = true;
	}

	//	Returns the number of lbs/gal in a kg/L.
	static final double theFactor = 3.785411784 / 0.45359237;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static PoundsPerGallon getInstance() {
		return example;
	}


}


