/*
*  PoundsPerInch3 - Density unit "pounds per cubic inch".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The British density unit: pounds per cubic inch.
*       Definition: (lb/in^3)/(lb/ft^3) = 1/1728  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 8, 1998
*  @version  November 17, 1999
**/
public final class PoundsPerInch3 extends DensityUnit {

	private static PoundsPerInch3 example = new PoundsPerInch3();

	private PoundsPerInch3() {
		name = "pounds per in\u00B3";
		abv = "lb/in\u00B3";
		exact = true;
	}

	//	Returns the number of lbs/in^3 in a kg/L.
	static final double theFactor = PoundsPerFoot3.theFactor / 1728.;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static PoundsPerInch3 getInstance() {
		return example;
	}

}


