/*
*  Slugs - The US mass unit "slugs".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The British mass unit: slugs.
*       Definition: slug/lb = 0.3048/9.80665   </p>
*
*  <p>  Is Exact?:   Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 18, 1997
*  @version  November 19, 1999
**/
public final class Slugs extends MassForceUnit {
	private static Slugs example = new Slugs();

	private Slugs() {
		name = "slugs";
		abv = "slug";
		exact = true;
	}

	//	Returns the number of slugs in a kilogram.
	static final double theFactor = Pounds.theFactor*0.3048/9.80665;
	protected double factor() { return theFactor; }


	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static Slugs getInstance() {
		return example;
	}

}


