/*
*  SlugsPerFoot3 - Density unit "pounds per cubic foot".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The British density unit: slugs per cubic foot.
*       Definition: (slugs/ft^3)/(lbs/ft^3) = 0.3048/9.80665  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 4, 1998
*  @version  November 17, 1999
**/
public final class SlugsPerFoot3 extends DensityUnit {

	private static SlugsPerFoot3 example = new SlugsPerFoot3();

	private SlugsPerFoot3() {
		name = "slugs per ft\u00B3";
		abv = "slugs/ft\u00B3";
		exact = true;
	}

	//	Returns the number of slugs/ft^3 in a gram/cm^3.
	static final double theFactor = PoundsPerFoot3 .theFactor * 0.3048 / 9.80665;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static SlugsPerFoot3 getInstance() {
		return example;
	}

}


