/*
*  SqFeet - British/American Area unit "square feet".
*
*  Copyright (C) 1998 - 2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;


/**
*  <p>  The area unit: square foot.
*       Definition: ft^2/m^2 = 1/0.09290304
*  </p>
*
*  <p>  Is Exact?: Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date: December 16, 1997
*  @version  May 19, 2002
**/
public final class SqFeet extends AreaUnit {

	private static SqFeet example = new SqFeet();

	private SqFeet() {
		name = "square feet";
		abv = "ft\u00B2";
		exact = true;
	}

	static final double theFactor = 1. / 0.09290304;

	/**
	*  Returns the number of sq feet in a sq meter.
	**/
	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static SqFeet getInstance() {
		return example;
	}


}


