/*
*  SqKilometers - SI Area unit "square kilometers".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The area unit: square kilometer.
*       Definition: km^2/m^2 = 1/1.0e+6
*  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 16, 1997
*  @version  February 6, 2000
**/
public final class SqKilometers extends AreaUnit {

	private static SqKilometers example = new SqKilometers();

	private SqKilometers() {
		name = "square kilometers";
		abv = "km\u00B2";
		exact = true;
	}

	//	Returns the number of sq kilometers in a sq meter.
	static final double theFactor = 1.0e-6;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static SqKilometers getInstance() {
		return example;
	}


}


