/*
*  SqYards - British/American area unit "square yards".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The area unit: square yard.
*       Definition: yd^2/ft^2 = 1/9
*  </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  December 16, 1997
*  @version  February 6, 2000
**/
public final class SqYards extends AreaUnit {

	private static SqYards example = new SqYards();

	private SqYards() {
		name = "square yards";
		abv = "yd\u00B2";
		exact = true;
	}

	//	Returns the number of square yards in a sq meter.
	static final double theFactor = SqFeet.theFactor / 9.;

	protected double factor() {
		return theFactor;
	}

	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static SqYards getInstance() {
		return example;
	}


}


