/*
*  TroyOunces - The troy weight unit "troy ounces".
*
*  Copyright (C) 1998-2002 by Joseph A. Huwaldt <jhuwaldt@knology.net>.  
*  All rights reserved.
*
*  This library is free software; you can redistribute it and/or
*  modify it under the terms of the GNU Library General Public
*  License as published by the Free Software Foundation; either
*  version 2 of the License, or (at your option) any later version.
*
*  This library is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*  Library General Public License for more details.
**/
package jahuwaldt.tools.units;



/**
*  <p>  The Troy weight unit: troy ounce.
*       Definition: troy ounce/kg = 1/0.0311034768   </p>
*
*  <p>  Is Exact?:  Yes  </p>
*
*  <p>  Modified by:   Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  January 6, 1998
*  @version  November 19, 1999
**/
public final class TroyOunces extends MassForceUnit {
	private static TroyOunces example = new TroyOunces();

	private TroyOunces() {
		name = "troy ounces";
		abv = "troy oz";
		exact = true;
	}

	//	Returns the number of troy ounces in a kilogram.
	static final double theFactor =1./0.0311034768;
	protected double factor() { return theFactor; }


	/**
	*  Return a reference to the one and only instance of this class.
	**/
	public static TroyOunces getInstance() {
		return example;
	}

}


